/*******************************************************************************
Copyright (C) 2008, LUMANTEK Co., Ltd.,  (http://www.lumantek.com)

VtsAPI.h

VtsAPI Class Declaration. C++ API for Ventus Series

History:
	[Version 2.0.0]
	 - Support Analog FM, HD Radio, Ventus A Plus(Tuner)
	 - Support License 30MHz ~ 1GHz, 30MHz ~ 2.5GHz, 1GHz ~ 2.5GHz

	[Version 1.9.7]
	 - Improved DVB-T2 Modulator API.

	[Version 1.9.6]
	 - Fixed the bug of parsing TS file of DVB-S2.

	[Version 1.9.5]
	 - Restored the missing code on DTMB Modulator.

	[Version 1.9.4]
	-  DVB-T2 Modulator

	[Version 1.9.3]

	- Support Modulator on Ventus2.0: 

		=> 1GHz Over or Under License

	[Version 1.9.2]

	- Support Modulator on Ventus2.0: 

		=> DVB-T/H, DVB-C, DAB, OpenCable, DVB-S, DVB-S2, ATSC, ATSC-M/H, ISDB-T, CMMB (No DTMB)
		=> 4CGX75 is changed

	[Version 1.9.1]

	- Support Modulator on Ventus2.0: 

		=> DVB-S, DVB-S2

	[Version 1.9.0]
	
	- Support for Ventus1.0, Ventus2.0, Vetnus-A, Sirch, Ventus-F1
	
	- Support Modulator :
	
		=>DVB-T/H, DVB-C, DAB, OpenCable, DTMB, ATSC, ATSC-M/H, ISDB-T, CMMB (Ventus1.0)
		
		=>ATSC, ATSC-M/H, DVB-S(Ventus2.0)
		
	- DAB recofiguration issue is fixed
	
	[Version 1.8.0]

	[Version 1.7.0]
	- Test Released
	
	[Version 1.6.0]
	- Test Released

	[Version 1.5.0]
	- Test Released

	[Version 1.4.0]
	
	[Version 1.3.0]

*******************************************************************************/


#ifndef _CVTSAPI_H
#define _CVTSAPI_H

#include "Ventus.h"

#define VTS_API_FNC extern "C" __declspec(dllexport)

#define VTS_API_VERSION_MAJOR	2
#define VTS_API_VERSION_MINOR	0 
#define VTS_API_VERSION_BUILD	0

#define VTS_API_MAX_ADAPTER		4
#define VTS_API_DEVICE_PATH_MAX	255
#define VTS_API_DEVICE_SN_LENGTH 20

//VtsAPI Class Declaration ///////////////////////////////////////////////////////

enum VTS_ATTEN_ID_e
{
	VTS_ATTEN_ID_ATTENPLUS		= 0x01, 	/*50MHz ~ 870MHz, +10.0 ~ -110.0*/
	VTS_UP_CONV				= 0x01, 
	VTS_SKYBAND_ID				= 0x02,
	VTS_ATTENF1_ID_ATTENPLUS	= 0x03, 	/*+10.0 ~ -30.0*/
	VTS_ATTENF1_ID_ATTENPLUS2  = 0x04,	/*+20.0 ~ -20.0*/
	VTS_WV_DOWN_CONV_ID		= 0x05,
	VTS_WV_ATTEN_A			= 0x06,	/*50MHz ~ 1GHz, +-30dB*/
	VTS_SIRCH_UP_CONV			= 0x07,	/*50MHz ~ 870MHz, +7.0 ~ -20.0*/
	VTS2_UP_CONV				= 0x08,	/*30MHz ~ 2.5GHZ*/ //mskang
	VTS2_ATTEN_ID				= 0x09,	/*30MHz ~ 1GHz : max +7dBm, 1G ~ 2.5GHz : max + 3dBm*///mskang_20120224	
	VTS2_WV2_DOWN_CONV_ID	= 0x0a,	/*100KHz ~ 2.7GHz*/
	VTS2_WV2_UP_CONV_ID		= 0x0b,	/*100KHz ~ 2.7GHz*/
	VTS2_WV2_ATTEN_A			= 0x0c,	/*100KHz ~ 2.7GHz*/

};


VTS_API_FNC	VTS_Return_t VtsAPI_Initialize(void);
VTS_API_FNC	VTS_Return_t VtsAPI_Finalize(void);
VTS_API_FNC char*		 GetApiVersionString(void);
VTS_API_FNC VTS_ApiVersion_t GetApiVersion(void);
VTS_API_FNC VTS_Return_t	 GetDriverVersion(VTS_DriverVersion_t* tp_DriverVersion);

// Device handle functions /////////////////////////////////////////////////
VTS_API_FNC int 			CountDevice(void);
VTS_API_FNC VTS_Return_t	OpenDevice(int s4_DeviceIndex);
VTS_API_FNC VTS_Return_t	CloseDevice(void);
VTS_API_FNC bool			CheckDevice(void);
VTS_API_FNC int 			GetDeviceIndex(void);
VTS_API_FNC VTS_Return_t	GetDevicePath(int s4_DeviceIndex, char* s1p_DevicePath);
VTS_API_FNC VTS_Return_t	GetSerialNum(int s4_DeviceIndex, char* s1p_SerialNum);


////////////////////////////////////////////////////////////////////////////

// Data Pump Control Methods ///////////////////////////////////////////////
VTS_API_FNC VTS_Return_t	PumpGetID(int s4_DeviceIndex, VTS_PumpID_t* tp_PumpID);

VTS_API_FNC VTS_Return_t	PumpSetState(VTS_PumpState_t t_PumpState);
VTS_API_FNC VTS_Return_t	PumpGetState(VTS_PumpState_t* tp_PumpState);

VTS_API_FNC VTS_Return_t	PumpGetHwBuffSize(unsigned int* u4p_HwBuffSize); // in Bytes
VTS_API_FNC VTS_Return_t	PumpGetHwBuffUsed(unsigned int* u4p_HwBuffUsed, unsigned int* u4p_RxBuffUsed); // in Bytes

VTS_API_FNC VTS_Return_t	PumpGetRxBuffUnderRun(int* s4p_UnderRun);
VTS_API_FNC VTS_Return_t	PumpGetTxBuffUnderRun(int* s4p_UnderRun);

VTS_API_FNC VTS_Return_t	PumpSetMode(
						VTS_PumpMode_t t_PumpMode,
						bool b_RemuxOnOff,
						VTS_TS_Format_t t_OutTsFormat,
						VTS_TS_Format_t t_SrcTsFormat);
VTS_API_FNC VTS_Return_t	PumpGetMode(
						VTS_PumpMode_t* tp_PumpMode,
						bool* bp_RemuxOnOff,
						VTS_TS_Format_t* tp_OutTsFormat,
						VTS_TS_Format_t* tp_SrcTsFormat);

VTS_API_FNC VTS_Return_t	PumpSetControl(
						bool b_ModResetN,
						bool b_AttResetN,
						bool b_AsiEqBypass,
						bool b_AsiLoopbackEnable);
VTS_API_FNC VTS_Return_t	PumpGetControl(
						bool* bp_ModResetN,
						bool* bp_AttResetN,
						bool* bp_AsiEqBypass,
						bool* bp_AsiLoopbackEnable,
						bool* bp_AsiEqCarrierDetectN,
						bool* bp_AsiRx188_204
						);

VTS_API_FNC VTS_Return_t	PumpSetRawRate(unsigned int u4_bps);
VTS_API_FNC VTS_Return_t	PumpGetRawRate(unsigned int* u4p_bps);

VTS_API_FNC VTS_Return_t	PumpSetConvRate(unsigned int u4_bps);
VTS_API_FNC VTS_Return_t	PumpGetConvRate(unsigned int* u4p_bps);

VTS_API_FNC VTS_Return_t	PumpGetRxRate(unsigned int* u4p_bps); // for ASI-IN of ASI-RF
VTS_API_FNC VTS_Return_t	PumpWrite(
						unsigned char* u1p_Buff,
						unsigned int u4_dwWrite, 
						unsigned long* u4p_TransferedBytes,
						bool b_IsDSLFormatForDABModulator
					);
VTS_API_FNC VTS_Return_t	PumpRead(
						unsigned char* u1p_Buff,
						unsigned int u4_dwRead,
						unsigned long* u4p_TransferedBytes
					);
VTS_API_FNC VTS_Return_t	PumpGetBcTypeSupport(VTS_BroadcastType_t t_BcType); // Check the Broadcast type capability
VTS_API_FNC VTS_Return_t	PumpGetAwgnLicence(void);
VTS_API_FNC VTS_Return_t	PumpGetAtscMhMuxLicense(void);
VTS_API_FNC VTS_Return_t	PumpGetDmbMuxLicense(void);

VTS_API_FNC VTS_Return_t PumpGetMaxSrcRate(unsigned int* u4p_bps);
VTS_API_FNC VTS_Return_t PumpGetMinSrcRate(unsigned int* u4p_bps);
VTS_API_FNC VTS_Return_t PumpGetMaxConvRate(unsigned int* u4p_bps);
VTS_API_FNC VTS_Return_t PumpGetMinConvRate(unsigned int* u4p_bps);
VTS_API_FNC VTS_Return_t PumpGetMaxSymRate(unsigned int* u4p_bps);
VTS_API_FNC VTS_Return_t PumpGetMinSymRate(unsigned int* u4p_bps);
VTS_API_FNC bool Pump_DMA_Q_IsFree(void);

////////////////////////////////////////////////////////////////////////////

// Modulator/UpConverter control methods ///////////////////////////////////
// Query Methods
VTS_API_FNC VTS_Return_t	ModulatorGetID(VTS_ModulatorID_t* tp_ModulatorID);
VTS_API_FNC VTS_Return_t	ModulatorGetRFMax(unsigned int* u4p_Hz);
VTS_API_FNC VTS_Return_t	ModulatorGetRFMin(unsigned int* u4p_Hz);

VTS_API_FNC VTS_Return_t	ModulatorInit(VTS_BroadcastType_t t_BcType);

VTS_API_FNC VTS_Return_t	ModulatorSetBcType(VTS_BroadcastType_t t_BcType);
VTS_API_FNC VTS_Return_t	ModulatorGetBcType(VTS_BroadcastType_t* tp_BcType);

VTS_API_FNC VTS_Return_t	ModulatorSetRF(unsigned int u4_Hz);
VTS_API_FNC VTS_Return_t	ModulatorGetRF(unsigned int *u4p_Hz);

VTS_API_FNC VTS_Return_t	ModulatorSetIF(unsigned int u4_Hz);
VTS_API_FNC VTS_Return_t	ModulatorGetIF(unsigned int *u4p_Hz);

VTS_API_FNC VTS_Return_t	AWGN_Set_CN(double s8_SNR_dBm, double s8_BW);
VTS_API_FNC VTS_Return_t	AWGN_ON_OFF(bool isOnOff);

// Diagnostic methods
VTS_API_FNC VTS_Return_t	ModulatorGetPllStatus(
	bool* bp_IF1_Locked, // Baseband to Low IF Up Conversion
	bool* bp_IF2_Locked, // Low IF to High IF Up Conversion !! Not implemented, Always TRUE !!
	bool* bp_RF_Locked); // High IF to RF Down Conversion & Spectrum Inversion  !! Not implemented, Always TRUE !!

// DVB-T/H Specific Methods
VTS_API_FNC VTS_Return_t	DVB_TH_SetBandWidth(unsigned char u1_MHz);
VTS_API_FNC VTS_Return_t	DVB_TH_GetBandWidth(unsigned char* u1p_MHz);

VTS_API_FNC VTS_Return_t	DVB_TH_GetSymRate(unsigned int* u4p_SymRate_bd);
VTS_API_FNC VTS_Return_t	DVB_TH_GetBitRate(unsigned int* u4p_BitRate_bps);

VTS_API_FNC VTS_Return_t	DVB_TH_SetCellID(unsigned short u2_CellID);
VTS_API_FNC VTS_Return_t	DVB_TH_GetCellID(unsigned short *u2p_CellID);

VTS_API_FNC VTS_Return_t	DVB_TH_SetMode(
					bool b_CellIDEn,
					VTS_DVB_TH_Interleaver_t t_Interleaver,
					bool b_UseMPE_FEC,
					bool b_UseTimeSlicing,
					bool b_DVBHEnable,
					VTS_DVB_TH_GuardInt_t t_GuardInt,
					VTS_DVB_TH_TxMode_t t_TxMode,
					VTS_DVB_TH_Constel_t t_Constel,
					VTS_DVB_TH_CodeRate_t t_CodeRate
				);
VTS_API_FNC VTS_Return_t	DVB_TH_GetMode(
					bool* bp_CellIDEn,
					VTS_DVB_TH_Interleaver_t* tp_Interleaver,
					bool* bp_UseMPE_FEC,
					bool* bp_UseTimeSlicing,
					bool* bp_DVBHEnable,
					VTS_DVB_TH_GuardInt_t* tp_GuardInt,
					VTS_DVB_TH_TxMode_t* tp_TxMode,
					VTS_DVB_TH_Constel_t* tp_Constel,
					VTS_DVB_TH_CodeRate_t* tp_CodeRate
				);

VTS_API_FNC VTS_Return_t	DVB_TH_SetCellIDEn(bool b_Enable);
VTS_API_FNC VTS_Return_t	DVB_TH_GetCellIDEn(bool* bp_Enable);
VTS_API_FNC VTS_Return_t	DVB_TH_SetInterleaver(VTS_DVB_TH_Interleaver_t t_Interleaver);
VTS_API_FNC VTS_Return_t	DVB_TH_GetInterleaver(VTS_DVB_TH_Interleaver_t* tp_Interleaver);
VTS_API_FNC VTS_Return_t	DVB_TH_SetMPE_FEC(bool b_Use);
VTS_API_FNC VTS_Return_t	DVB_TH_GetMPE_FEC(bool* bp_Use);
VTS_API_FNC VTS_Return_t	DVB_TH_SetTimeSlicing(bool b_Use);
VTS_API_FNC VTS_Return_t	DVB_TH_GetTimeSlicing(bool* bp_Use);
VTS_API_FNC VTS_Return_t	DVB_TH_SetDVBHEnable(bool b_Enable);
VTS_API_FNC VTS_Return_t	DVB_TH_GetDVBHEnable(bool* bp_Enable);
VTS_API_FNC VTS_Return_t	DVB_TH_SetGuardInt(VTS_DVB_TH_GuardInt_t t_GuardInt);
VTS_API_FNC VTS_Return_t	DVB_TH_GetGuardInt(VTS_DVB_TH_GuardInt_t* tp_GuardInt);
VTS_API_FNC VTS_Return_t	DVB_TH_SetTxMode(VTS_DVB_TH_TxMode_t t_TxMode);
VTS_API_FNC VTS_Return_t	DVB_TH_GetTxMode(VTS_DVB_TH_TxMode_t* tp_TxMode);
VTS_API_FNC VTS_Return_t	DVB_TH_SetConstel(VTS_DVB_TH_Constel_t t_Constel);
VTS_API_FNC VTS_Return_t	DVB_TH_GetConstel(VTS_DVB_TH_Constel_t* tp_Constel);
VTS_API_FNC VTS_Return_t	DVB_TH_SetCodeRate(VTS_DVB_TH_CodeRate_t t_CodeRate);
VTS_API_FNC VTS_Return_t	DVB_TH_GetCodeRate(VTS_DVB_TH_CodeRate_t* tp_CodeRate);

// DVB-C Specific Methods
VTS_API_FNC VTS_Return_t	DVB_C_SetSymRate(unsigned int u4_DVBCSymRateBd);
VTS_API_FNC VTS_Return_t	DVB_C_GetSymRate(unsigned int* u4p_SymRate_bd);

VTS_API_FNC VTS_Return_t	DVB_C_SetBitRate(unsigned int u4_BitRate_bps);
VTS_API_FNC VTS_Return_t	DVB_C_GetBitRate(unsigned int* u4p_BitRate_bps);

VTS_API_FNC VTS_Return_t	DVB_C_GetBandWidth(unsigned int* u4p_BW_Hz);

VTS_API_FNC VTS_Return_t	DVB_C_SetConstel(VTS_DVB_C_Constel_t t_Constel);
VTS_API_FNC VTS_Return_t	DVB_C_GetConstel(VTS_DVB_C_Constel_t* tp_Constel);

//DVB-S Specific Methods
VTS_API_FNC VTS_Return_t	DVB_S_SetSymRate(unsigned int u4_DVBSSymRateBd);
VTS_API_FNC VTS_Return_t	DVB_S_GetSymRate(unsigned int* u4p_SymRate_bd);

VTS_API_FNC VTS_Return_t	DVB_S_GetBitRate(unsigned int* u4p_BitRate_bps);
VTS_API_FNC VTS_Return_t	DVB_S_GetBandWidth(unsigned int* u4p_BW_Hz);

VTS_API_FNC VTS_Return_t	DVB_S_SetConstel(VTS_DVB_S_Constel_t t_Constel);
VTS_API_FNC VTS_Return_t	DVB_S_GetConstel(VTS_DVB_S_Constel_t* tp_Constel);

VTS_API_FNC VTS_Return_t	DVB_S_SetCodeRate(VTS_DVB_S_CodeRate_t t_CodeRate);
VTS_API_FNC VTS_Return_t	DVB_S_GetCodeRate(VTS_DVB_S_CodeRate_t* tp_CodeRate);


// QAM-B Specific Methods
VTS_API_FNC VTS_Return_t	QAM_B_GetSymRate(unsigned int* u4p_SymRate_bd);
VTS_API_FNC VTS_Return_t	QAM_B_GetBandWidth(unsigned int* u4p_BW_Hz);
VTS_API_FNC VTS_Return_t	QAM_B_GetBitRate(unsigned int* u4p_BitRate_bps);

VTS_API_FNC VTS_Return_t	QAM_B_SetConstel(VTS_QAM_B_Constel_t t_Constel);
VTS_API_FNC VTS_Return_t	QAM_B_GetConstel(VTS_QAM_B_Constel_t* tp_Constel);
VTS_API_FNC VTS_Return_t	QAM_B_SetInterleaving(VTS_QAM_B_Interleaving_t t_Interleaving);
VTS_API_FNC VTS_Return_t	QAM_B_GetInterleaving(VTS_QAM_B_Interleaving_t* tp_Interleaving);

VTS_API_FNC VTS_Return_t	QAM_B_SetMode(
					VTS_QAM_B_Constel_t t_Constel,
					VTS_QAM_B_Interleaving_t t_Interleaving
				);
VTS_API_FNC VTS_Return_t	QAM_B_GetMode(
					VTS_QAM_B_Constel_t* t_Constel,
					VTS_QAM_B_Interleaving_t* t_Interleaving
				);

//ATSC Specific methods
VTS_API_FNC VTS_Return_t	ATSC_GetBandWidth(unsigned int* u4p_BW_Hz);
VTS_API_FNC VTS_Return_t	ATSC_GetSymRate(unsigned int* u4p_SymRate_bd);
VTS_API_FNC VTS_Return_t	ATSC_GetBitRate(unsigned int* u4p_BitRate_bps);



// T-DMB Specific Methods
VTS_API_FNC VTS_Return_t	T_DMB_GetBandWidth(unsigned int* u4p_BW_Hz);
VTS_API_FNC VTS_Return_t	T_DMB_GetBitRate(unsigned int* u4p_BitRate_bps);
VTS_API_FNC VTS_Return_t	T_DMB_GetSymRate(unsigned int* u4p_SymRate_bd);
VTS_API_FNC VTS_Return_t	T_DMB_SetTii(
					bool b_Enable,
					unsigned char u1_MainId,
					unsigned char u1_SubId
				);
VTS_API_FNC VTS_Return_t	T_DMB_GetTii(
					bool* bp_Enable,
					unsigned char* u1p_MainId,
					unsigned char* u1p_SubId
				);
VTS_API_FNC VTS_Return_t	T_DMB_Parse(unsigned char* u1p_Buff, unsigned int u4_Size, bool b_IsDSLFormat);
VTS_API_FNC VTS_Return_t	T_DMB_GetMode(int* s4p_Mode);
VTS_API_FNC VTS_Return_t	T_DMB_GetBufferOffset(int* s4p_Offset);
VTS_API_FNC VTS_Return_t	T_DMB_GetFramePhase(int* s4p_Phase);

// ISDB_T Specific Methods
VTS_API_FNC VTS_Return_t	ISDBT_SetBandWidth(unsigned char u1_MHz);
VTS_API_FNC VTS_Return_t	ISDBT_GetBandWidth(unsigned char* u1p_MHz);
VTS_API_FNC VTS_Return_t	ISDB_T_GetSymRate(unsigned int* u4p_SymRate_bd);
VTS_API_FNC VTS_Return_t	ISDBT_ParseFromBuffer(unsigned char *u1p_Buff, int s4_Size_Byte);
VTS_API_FNC VTS_Return_t	ISDBT_Parse(const char* p_FilePath);
VTS_API_FNC VTS_Return_t	ISDBT_Parse_W(const wchar_t* p_FilePath);
VTS_API_FNC VTS_Return_t	ISDBT_GetBufferOffset(int *s4p_Offset);
VTS_API_FNC VTS_Return_t	ISDBT_GetFrameSize(int *s4p_FrameSize);		
VTS_API_FNC VTS_Return_t	ISDBT_SetParameter(VTS_ISDB_T_Layer_t t_Layer, ISDB_Layer_Parameter_t t_NewParameter);
VTS_API_FNC VTS_Return_t	ISDBT_GetParameter(
					ISDB_Layer_Parameter_t* tp_Layer_A,
					ISDB_Layer_Parameter_t* tp_Layer_B,
					ISDB_Layer_Parameter_t* tp_Layer_C,
					ISDB_OfdmConfig_t* tp_OfdmConfig
				);
VTS_API_FNC ISDB_Layer_Parameter_t ISDBT_GetLayerParameter(VTS_ISDB_T_Layer_t t_Layer);
VTS_API_FNC VTS_Return_t	ISDBT_GetTotalOutBitRate(unsigned int *u4p_BitRatebps);
VTS_API_FNC VTS_Return_t	ISDBT_GetLayerOutBitRate(unsigned int* u4p_BitRateBps, VTS_ISDB_T_Layer_t t_Layer);
VTS_API_FNC VTS_Return_t	ISDBT_GetLayerSrcBitRate(unsigned int* u4p_BitRateBps, VTS_ISDB_T_Layer_t t_Layer);
VTS_API_FNC VTS_Return_t	ISDBT_GetTotalSrcBitRate(unsigned int* u4p_BitRateBps);
VTS_API_FNC VTS_Return_t	ISDBT_GetTspNumPerFrame(unsigned int *u4p_TspNumPerFrame);	
VTS_API_FNC VTS_Return_t	ISDBT_IsISDBT_TS(const char* p_FilePath, bool *b_IsIsdbtTs);
VTS_API_FNC VTS_Return_t	ISDBT_IsISDBT_TS_W(const wchar_t* p_FilePath, bool *b_IsIsdbtTs);	
VTS_API_FNC VTS_Return_t	ISDBT_SetOfdmConfig(ISDB_OfdmConfig_t t_NewConfig);
VTS_API_FNC ISDB_OfdmConfig_t ISDBT_GetOfdmConfig();	
VTS_API_FNC VTS_Return_t	ISDBT_SetFullSegOut(bool b_IsFullSegOut);
VTS_API_FNC VTS_Return_t	ISDBT_GetFullSegOut(bool* bp_IsFullSegOut);	
VTS_API_FNC VTS_Return_t	ISDBT_SetEws(bool b_SetEws);
VTS_API_FNC VTS_Return_t	ISDBT_GetEws(bool *bp_SetEws);

// CMMB Specific Methods	
VTS_API_FNC VTS_Return_t	CMMB_GetSymRate(unsigned int* u4p_SymRate_bd);
VTS_API_FNC VTS_Return_t	CMMB_IsCMMB_TS(const char* p_FilePath, bool* b_IsCmmbTs);
VTS_API_FNC VTS_Return_t	CMMB_IsCMMB_TS_W(const wchar_t* p_FilePath, bool* b_IsCmmbTs);
VTS_API_FNC VTS_Return_t	CMMB_CHECK_SYNC(const char* p_FilePath, unsigned __int64 u8_CurrentPosition, int* s4p_Offset, int* s4p_FrameSize, 
								bool IsMultiCh, CmmbConfig_t t_Config, unsigned char* u1p_Buffer);
VTS_API_FNC VTS_Return_t	CMMB_CHECK_SYNC_W(const wchar_t* p_FilePath, unsigned __int64 u8_CurrentPosition, int* s4p_Offset, int* s4p_FrameSize, 
								bool IsMultiCh, CmmbConfig_t t_Config, unsigned char* u1p_Buffer);
VTS_API_FNC CmmbClchCheck_t	CMMB_PARSING(const char* p_FilePath, bool* bp_IsMultiCh, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
VTS_API_FNC CmmbClchCheck_t	CMMB_PARSING_W(const wchar_t* p_FilePath, bool* bp_IsMultiCh, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
VTS_API_FNC VTS_Return_t	CMMB_GetConfig(CmmbConfig_t* tp_Config);
VTS_API_FNC VTS_Return_t	CMMB_GetChangeableTSlot(CmmbConfig_t* tp_Config);
VTS_API_FNC VTS_Return_t	CMMB_ChangeParameter(unsigned char u1_MfId, CmmbInformation_t t_Parameter);
VTS_API_FNC VTS_Return_t	CMMB_Initial();	
VTS_API_FNC VTS_Return_t	CMMB_GetRevision(CmmbConfig_t t_Config, bool IsMulti, double* f8p_Revision);
VTS_API_FNC VTS_Return_t	CMMB_AddSMfs(const char* p_FilePath, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
VTS_API_FNC VTS_Return_t	CMMB_AddSMfs_W(const wchar_t* p_FilePath, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
VTS_API_FNC VTS_Return_t	CMMB_DeleteSMfs(int s4_MfId);	
VTS_API_FNC VTS_Return_t	CMMB_GetOutBitRate(unsigned int* u4p_OutBitRate);
VTS_API_FNC VTS_Return_t	CMMB_GetMfOutBitRate(unsigned int* u4p_OutBitRate, int s4_MfId);		//bit rate for individual MF
VTS_API_FNC int			CMMB_CheckMfSize(bool b_IsMulti, unsigned char u1_MfId, unsigned char* u1p_Buffer);
VTS_API_FNC VTS_Return_t	CMMB_TransTs2Mfs(unsigned char* u1p_Buffer, int s4_Size);
VTS_API_FNC bool*		CMMB_GetEmptyFrame();

//DTMB Specific Methods
VTS_API_FNC VTS_Return_t	DTMB_Initial();
VTS_API_FNC VTS_Return_t	DTMB_IsDTMBTS(const char* p_FilePath, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
VTS_API_FNC VTS_Return_t	DTMB_IsDTMBTS_W(const wchar_t* p_FilePath, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
VTS_API_FNC VTS_Return_t	DTMB_GetSrcBitRate(int* s4p_BitRate);
VTS_API_FNC VTS_Return_t	DTMB_GetOutBitRate(int* s4p_BitRate);
VTS_API_FNC VTS_Return_t	DTMB_GetSymRate(unsigned int* u4p_SymRate_bd);	
VTS_API_FNC VTS_Return_t	DTMB_GetRevision(VTS_DTMB_CONFIG_t t_Config, double* f8p_Revision, int s4_TsLength);

VTS_API_FNC VTS_Return_t	DTMB_SetMode(VTS_DTMB_CONFIG_t t_Config, unsigned int* u4p_NewFrameSz);
VTS_API_FNC VTS_Return_t	DTMB_GetMode(VTS_DTMB_CONFIG_t* tp_Config);



//DVB-S2 Specific Methods
VTS_API_FNC VTS_Return_t	DVBS2_Initial();

VTS_API_FNC VTS_Return_t	DVBS2_ParseStream_W(const wchar_t* p_FilePath);
VTS_API_FNC VTS_Return_t	DVBS2_ParseStream(const char* p_FilePath);
VTS_API_FNC VTS_Return_t	DVBS2_SetParam(unsigned int u4_SymRate_bd, VTS_DVB_S2_Constel_t t_Constellation, VTS_DVB_S2_CodeRate_t t_CodeRate, 
													bool b_IsPilotInsert, VTS_DVB_S2_Alpha_t t_RollOff);

VTS_API_FNC VTS_Return_t	DVBS2_GetSrcBitRate(unsigned int* u4p_BitRate_bps);
VTS_API_FNC VTS_Return_t	DVBS2_GetOutBitRate(unsigned int* u4p_BitRate_bps);	
VTS_API_FNC VTS_Return_t	DVBS2_GetBandwidth(unsigned int* u4p_BW_Hz);
VTS_API_FNC VTS_Return_t	DVBS2_GetDmaSize(unsigned int* u4p_DmaSize);

VTS_API_FNC VTS_Return_t	DVBS2_SetSymRate( unsigned int u4_SymRate_bd);	
VTS_API_FNC VTS_Return_t	DVBS2_GetSymRate(unsigned int* u4p_SymRate_bd);

VTS_API_FNC VTS_Return_t	DVBS2_SetConstellation(VTS_DVB_S2_Constel_t t_Constellation);
VTS_API_FNC VTS_Return_t	DVBS2_GetConstellation(VTS_DVB_S2_Constel_t* tp_Constellation);

VTS_API_FNC VTS_Return_t	DVBS2_SetCodeRate(VTS_DVB_S2_CodeRate_t t_CodeRate);
VTS_API_FNC VTS_Return_t	DVBS2_GetCodeRate(VTS_DVB_S2_CodeRate_t* tp_CodeRate);

VTS_API_FNC VTS_Return_t	DVBS2_SetRollOff(VTS_DVB_S2_Alpha_t t_RollOff);
VTS_API_FNC VTS_Return_t	DVBS2_GetRollOff(VTS_DVB_S2_Alpha_t* tp_RollOff);

VTS_API_FNC VTS_Return_t	DVBS2_SetPilotInsertion(bool b_IsPilotInsert);
VTS_API_FNC VTS_Return_t	DVBS2_GetPilotInsertion(bool* bp_IsPilotInsert);

//DVB-T2 Specific Methods
VTS_API_FNC VTS_Return_t	DVBT2_ParseStream(const char* sz_FilePath, bool b_IsT2Mi, bool b_IsReplace);
VTS_API_FNC VTS_Return_t	DVBT2_ParseStream_W(const wchar_t* sz_FilePath, bool b_IsT2Mi, bool b_IsReplace);
VTS_API_FNC VTS_Return_t	DVBT2_GetError(wchar_t* sz_ErrorString, int *s4p_StrLength);		//sz_ErrorString IAIAi CͨACAOa

VTS_API_FNC VTS_Return_t	DVBT2_SetFFT(VTS_DVBT2_FFT_SIZE_e e_FftSize);
VTS_API_FNC VTS_Return_t	DVBT2_SetGuardInterval(VTS_DVBT2_GI_e e_GuardInterval);
VTS_API_FNC VTS_Return_t	DVBT2_SetBW(VTS_DVBT2_BW_e e_BandWidth);
VTS_API_FNC VTS_Return_t	DVBT2_SetL1MOD(VTS_DVBT2_L1POSTMOD_e e_L1PostMod);
VTS_API_FNC VTS_Return_t	DVBT2_SetPilotPattern(VTS_DVBT2_PP_e e_Pp);
VTS_API_FNC VTS_Return_t	DVBT2_SetT2FramesPerSuperFrame(int s4_T2FramesN);
VTS_API_FNC VTS_Return_t	DVBT2_SetDataSymbolsN(int s4_DataSymbolsN);
VTS_API_FNC VTS_Return_t	DVBT2_SetVersion(VTS_DVBT2_VERSION_e e_Version);
VTS_API_FNC VTS_Return_t	DVBT2_SetSubSlicesN(int s4_SubSlicesN);
VTS_API_FNC VTS_Return_t	DVBT2_SetL1Repetion(bool b_L1Repetition);
VTS_API_FNC VTS_Return_t	DVBT2_SetBwtExt(bool b_BwtExt);	
VTS_API_FNC VTS_Return_t	DVBT2_SetT2SystemID(int s4_T2SystemID);
VTS_API_FNC VTS_Return_t	DVBT2_SetNetworkID(int s4_NetworkID);
VTS_API_FNC VTS_Return_t	DVBT2_SetCellID(int s4_CellID);	

VTS_API_FNC VTS_Return_t	DVBT2_SetPlpMaxBlock(int s4_PlpId, int s4_PlpMaxBlock);
VTS_API_FNC VTS_Return_t	DVBT2_SetPlpMapping(int s4_PlpId, VTS_DVBT2_PLP_MAPPING_e e_PlpMapping);
VTS_API_FNC VTS_Return_t	DVBT2_SetPlpRotation(int s4_PlpId, bool b_Rotation);
VTS_API_FNC VTS_Return_t	DVBT2_SetPlpCodeRate(int s4_PlpId, VTS_DVBT2_LDPC_e e_CodeRate);
VTS_API_FNC VTS_Return_t	DVBT2_SetPlpFecType(int s4_PlpId, VTS_DVBT2_FECTYPE_e e_FecType);
VTS_API_FNC VTS_Return_t	DVBT2_SetIntrlType(int s4_PlpId, int s4_IntrlType);
VTS_API_FNC VTS_Return_t	DVBT2_SetIntrlLength(int s4_PlpId, int s4_IntrlLength);
VTS_API_FNC VTS_Return_t	DVBT2_SetFrameInterval(int s4_PlpId, int s4_FrameInterval);
VTS_API_FNC VTS_Return_t	DVBT2_SetPlpType(int s4_PlpId, VTS_DVBT2_PlpType_e e_PlpType);



VTS_API_FNC VTS_Return_t	DVBT2_GetPlpN(int* s4p_PlpN);
VTS_API_FNC VTS_Return_t	DVBT2_GetPlpParam(int s4_PlpIndex, VTS_DVBT2_PLP_Infor_t* tp_PlpInfor);
VTS_API_FNC VTS_Return_t	DVBT2_GetGeneralParam(VTS_DVBT2_SYSTEM_Infor_t* tp_Infor);
VTS_API_FNC VTS_Return_t	DVBT2_GetDmaSize(unsigned int* s4p_DmaSize);

//ATSC-MH Specific Methods (Non-Multiplex Mode Support)
VTS_API_FNC VTS_Return_t ATSC_MH_Init(VOID);

VTS_API_FNC VTS_Return_t ATSC_MH_SetMainTSPath(wchar_t *wp_PathBuffer);
VTS_API_FNC VTS_Return_t ATSC_MH_GetMainTSPath(wchar_t *wp_PathBuffer, int s4_PathBufferLength);

VTS_API_FNC VTS_Return_t ATSC_MH_GetLegacyBitRate(unsigned int *u4p_BitRate_bps);

VTS_API_FNC VTS_Return_t ATSC_MH_SetUseLegacy(bool isUse);
VTS_API_FNC VTS_Return_t ATSC_MH_GetUseLegacy(bool* isUse);

VTS_API_FNC VTS_Return_t ATSC_MH_GetFrameSize(unsigned int* u4p_FrameSize);


// CW Specific Methods
VTS_API_FNC VTS_Return_t	CW_GetSymRate(unsigned int* u4p_SymRate_bd);
VTS_API_FNC VTS_Return_t	CW_SetLevel_20dBm(void); // Set Output level to -20dBm
VTS_API_FNC unsigned short	CW_GetLevelCtrl_20dBm(void);
VTS_API_FNC VTS_Return_t	CW_SetLevelCtrl(unsigned short u2_LevelCtrl); // Output Level Control Coef.
VTS_API_FNC VTS_Return_t	CW_GetLevelCtrl(unsigned short* u2p_LevelCtrl);
VTS_API_FNC unsigned short	CW_GetLevelCtrlMax(void);

VTS_API_FNC VTS_Return_t	Analog_FM_SetSymRate(unsigned int u4_SymRateBd);
VTS_API_FNC VTS_Return_t	Analog_FM_GetSymRate(unsigned int *u4p_SymRate_bd);
VTS_API_FNC VTS_Return_t	Analog_FM_GetBitRate(unsigned int *u4p_BitRate_bps);
VTS_API_FNC VTS_Return_t	Analog_FM_GetBandWidth(unsigned int *u4p_BW_Hz);
VTS_API_FNC VTS_Return_t	Analog_FM_SetArbRate(unsigned int u4_ArbRateHz);
VTS_API_FNC VTS_Return_t	Analog_FM_GetArbRate(unsigned int *u4p_ArbRateHz);
VTS_API_FNC VTS_Return_t	Analog_FM_SetDevFactor(unsigned int u4_DevFactor); // Deviation Factor
VTS_API_FNC VTS_Return_t	Analog_FM_GetDevFactor(unsigned int *u4p_DevFactor); // Deviation Factor
VTS_API_FNC VTS_Return_t	Analog_FM_SetArbBypassFlag(unsigned int u4_bypassFlag);
VTS_API_FNC VTS_Return_t	Analog_FM_GetArbBypassFlag(unsigned int *u4p_bypassFlag);
VTS_API_FNC VTS_Return_t	Analog_FM_SetInt2xBypassFlag(unsigned int u4_bypassFlag);
VTS_API_FNC VTS_Return_t	Analog_FM_GetInt2xBypassFlag(unsigned int *u4p_bypassFlag);
VTS_API_FNC VTS_Return_t	Analog_FM_SetDevTestMode(unsigned int u4_testFlag);
VTS_API_FNC VTS_Return_t	Analog_FM_GetDevTestMode(unsigned int *u4p_testFlag);	
VTS_API_FNC VTS_Return_t	Analog_FM_SetDevTestValue(unsigned int u4_testVal);
VTS_API_FNC VTS_Return_t	Analog_FM_GetDevTestValue(unsigned int *u4p_testVal);
VTS_API_FNC VTS_Return_t	Analog_FM_SetAwgn(unsigned int u4_awgn);
VTS_API_FNC VTS_Return_t	Analog_FM_GetAwgn(unsigned int *u4p_awgn);	
VTS_API_FNC VTS_Return_t	Hdradio_SetSymRate(unsigned int u4_SymRateBd);	
VTS_API_FNC VTS_Return_t	Hdradio_GetSymRate(unsigned int *u4p_SymRate_bd);	
VTS_API_FNC VTS_Return_t	Hdradio_GetBitRate(unsigned int *u4p_BitRate_bps);	
VTS_API_FNC VTS_Return_t	Hdradio_GetBandWidth(unsigned int *u4p_BW_Hz);	
VTS_API_FNC VTS_Return_t	Hdradio_SetArbRate(unsigned int u4_ArbRateHz);	
VTS_API_FNC VTS_Return_t	Hdradio_GetArbRate(unsigned int *u4p_ArbRateHz);
VTS_API_FNC VTS_Return_t	Hdradio_SetFlags(unsigned int u4_flags);	
VTS_API_FNC VTS_Return_t	Hdradio_GetFlags(unsigned int *u4p_flags);
VTS_API_FNC VTS_Return_t Hdradio_SetArbBypassFlag(bool b_bypassFlag);	
VTS_API_FNC VTS_Return_t	Hdradio_GetArbBypassFlag(bool *bp_bypassFlag);
VTS_API_FNC VTS_Return_t	Hdradio_SetInt2xBypassFlag(bool b_bypassFlag);
VTS_API_FNC VTS_Return_t	Hdradio_GetInt2xBypassFlag(bool *bp_bypassFlag);	
//-------------------------------------------------------------------------------
//VentusAPlus Tuner
//-------------------------------------------------------------------------------
VTS_API_FNC int VentusAPlus_Tuner_CountDevice();
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_PowerDetect();
VTS_API_FNC VTS_Return_t  VentusAPlus_Tuner_Standard_Initialize(VTS_TunerStandard_t t_TunerStd);
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_SetFreq(unsigned int u4_FreqHz);
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetFreq(unsigned int *u4p_FreHz);
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetFreqSpec(unsigned int *u4p_FreqMinHz, unsigned int *u4p_FreqMaxHz);
//-------------------------------------------------------------------------------
//VentusAPlus Tuner In Path, In/Out Port Type
//-------------------------------------------------------------------------------
VTS_API_FNC VTS_Return_t VentusAPlus_Input_SetPath(VtsAPlus_RxPath_t t_Path);
VTS_API_FNC VTS_Return_t VentusAPlus_Input_GetPath(VtsAPlus_RxPath_t *tp_Path);

VTS_API_FNC VTS_Return_t VentusAPlus_Input_SetPortType(VtsAPlus_PortType_t t_Type);
VTS_API_FNC VTS_Return_t VentusAPlus_Input_GetPortType(VtsAPlus_PortType_t *tp_type);

VTS_API_FNC VTS_Return_t VentusAPlus_Output_SetPortType(VtsAPlus_PortType_t t_Type);
VTS_API_FNC VTS_Return_t VentusAPlus_Output_GetPortType(VtsAPlus_PortType_t *tp_type);

//-------------------------------------------------------------------------------
//VentusAPlus Tuner Get Info
//-------------------------------------------------------------------------------

//
//VentusAPlus_Tuner_GetSNR : VSB, QAM
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetSNR(double *d8p_SNR);

//
//VentusAPlus_Tuner_GetRSSI : VSB, QAM
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetRSSI(int *s4p_dBm);	

//
//VentusAPlus_Tuner_GetSyncLock :  VSB, QAM
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetSyncLock(bool *bp_IsSLock);

//
// VentusAPlus_Tuner_GetPacketErr :  VSB, QAM : (monitoring error counts in packets at every one second)
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetPacketErrCounts(unsigned short *u2p_PacketErrorCounts);

//
//VentusAPlus_Tuner_GetFreqOffset : VSB, QAM : monitoring offsets for the carrier frequency
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetFreqOffset(float *f4p_FreqOffset);

//
//VentusAPlus_Tuner_GetScat : VSB, QAM : monitoring I and Q of the constellation
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetScat(short *s2p_I, short *s2p_Q);

//
//VentusAPlus_Tuner_GetDCValue : VSB Only : monitoring DC Value of VSB DC Remover
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetDCValue(unsigned char *u1p_DCValue);

//
//VentusAPlus_Tuner_GetIntMode : VSB, QAM : monitoring the number of taps and the increases of the input signal
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetIntMode(unsigned char *u1p_I, unsigned char *u1p_J);

//
//VentusAPlus_Tuner_GetRFSignalCondition : VSB, QAM
//8vsb (No : ~0, weak : 0 ~10, moderate : 10 ~16, strong : 16 ~24, very strong : 24 ~)
//64qam (No : ~0, weak : 0 ~20, moderate : 20 ~25, strong : 26 ~30, very strong : 31 ~)
//256qam (No : ~0, weak : 0 ~28, moderate : 28 ~30, strong : 31 ~32, very strong : 33 ~)
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetRFSignalCondition(VtsAPlus_RFSignalCondition_t *tp_SignalCondition);

//
//VentusAPlus_Tuner_GetCarrierRecoveryLock : VSB, QAM
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetCarrierRecoveryLock(bool *bp_IsCRLock);

//
//VentusAPlus_Tuner_GetTimingRecoveryLock : QAM Only
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetTimingRecoveryLock(bool *bp_IsTRLock);

//
//VentusAPlus_Tuner_GetFECLock : QAM Only
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetFECLock(bool *bp_IsViterbi, bool *bp_IsFec, bool *bp_IsMpeg);

//-------------------------------------------------------------------------------
//VentusAPlus SMPTE
//-------------------------------------------------------------------------------
VTS_API_FNC VTS_Return_t VentusAPlus_Input_ASI_SMPTE_GetLock(bool *bp_IsASLock);
VTS_API_FNC VTS_Return_t VentusAPlus_Output_is_SMPTE_SetPLL(VtsAPlus_SMPTE_PLLType_t t_PLLType);

//-------------------------------------------------------------------------------
//VentusAPlus Temperature Monitoring
//-------------------------------------------------------------------------------
VTS_API_FNC VTS_Return_t VentusAPlus_Tuner_GetTemperature(char *s1p_Temperature);
////////////////////////////////////////////////////////////////////////////

// Amplifier & Attenuator, Level Controller module control methods /////////
VTS_API_FNC VTS_Return_t AttenGetID(VTS_AttenuatorID_t* tp_AttenuatorID);// If it fails, this module isn't attached.

VTS_API_FNC bool		 AttenGetExistence(void);

VTS_API_FNC VTS_Return_t AttenGetOutLevelMax(short* s2p_OutLevel_01dBm, short* s2p_1GHz_Over_OutLevel_01dBm_For_Ventus2);
VTS_API_FNC VTS_Return_t AttenGetOutLevelMin(short* s2p_OutLevel_01dBm, short* s2p_1GHz_Over_OutLevel_01dBm_For_Ventus2);

VTS_API_FNC VTS_Return_t AttenGetFrequencyMax(unsigned int* u4p_Freq_Hz);
VTS_API_FNC VTS_Return_t AttenGetFrequencyMin(unsigned int* u4p_Freq_Hz);

VTS_API_FNC VTS_Return_t AttenSetOutLevel(short s2_OutLevel_01dBm);
VTS_API_FNC VTS_Return_t AttenGetOutLevel(short* s2p_OutLevel_01dBm);
VTS_API_FNC VTS_Return_t AttenSetFrequency(unsigned int u4_Freq_Hz);
VTS_API_FNC VTS_Return_t AttenGetFrequency(unsigned int* u4p_Freq_Hz);
VTS_API_FNC VTS_Return_t AttenGetTemperature(char* s1p_Temp_Celsius);
VTS_API_FNC VTS_Return_t AttenSetOutSwitch(unsigned char u1_OnOff);
VTS_API_FNC VTS_Return_t AttenGetOutSwitch(unsigned char* u1p_OnOff);
////////////////////////////////////////////////////////////////////////////
VTS_API_FNC VTS_Return_t UpConvGetTemperature(char* s1p_Temp_Celsius);
VTS_API_FNC VTS_Return_t UpConvGetID(VTS_UpConverterID_t* tp_UpConvID); 


////////////////////////////////////////////////////////////////////////////
//For Sirch Model
////////////////////////////////////////////////////////////////////////////
VTS_API_FNC VTS_Return_t UpConvRfOutWatch(unsigned int* u4p_RfOutWatch);
VTS_API_FNC VTS_Return_t UpConvVoltageWatch(unsigned int* u4p_VoltageWatch);
////////////////////////////////////////////////////////////////////////////


VTS_API_FNC VTS_Return_t SkyBandGetID(VTS_SkyBandID_t* tp_SkyBandID); 
VTS_API_FNC bool		 SkyBandGetExistence(void);
VTS_API_FNC VTS_Return_t SkyBandGetOutLevelMax(short* s2p_OutLevelMax_01dBm);
VTS_API_FNC VTS_Return_t SkyBandGetOutLevelMin(short* s2p_OutLevelMin_01dBm);
VTS_API_FNC VTS_Return_t SkyBandGetFrequencySBandMax(unsigned int* u4p_S_BandRF_MaxHz);
VTS_API_FNC VTS_Return_t SkyBandGetFrequencySBandMin(unsigned int* u4p_S_BandRF_MinHz);
VTS_API_FNC VTS_Return_t SkyBandGetFrequencyLBandMax(unsigned int* u4p_L_BandRF_MaxHz);
VTS_API_FNC VTS_Return_t SkyBandGetFrequencyLBandMin(unsigned int* u4p_L_BandRF_MinHz);

////////////////////////////////////////////////////////////////////////////
/////////////////////////// EEPROM Read, Write //////////////////////////////
////////////////////////////////////////////////////////////////////////////
///////////////////EEPAddr : 1K(0 ~ 1023), DataSize : 1K/////////////////////////
////////////////////////////////////////////////////////////////////////////

VTS_API_FNC VTS_Return_t  EEPROM_SaveUserData(int EEPAddr, unsigned char* pBuffer, int NumBytesToSave);
VTS_API_FNC VTS_Return_t  EEPROM_LoadUserData(int EEPAddr, unsigned char* pBuffer, int BytesToLoad);

VTS_API_FNC VTS_Return_t GetFreeSizeOfBuffer(unsigned int* u4p_FreeSize);



class CVtsAPI
{
public:
	CVtsAPI();
	~CVtsAPI();		

	char*		 GetApiVersionString(void);
	VTS_ApiVersion_t GetApiVersion(void);
	VTS_Return_t	 GetDriverVersion(VTS_DriverVersion_t* tp_DriverVersion);

	// Device handle functions /////////////////////////////////////////////////
	int				CountDevice(void);
	VTS_Return_t	OpenDevice(int s4_DeviceIndex);
	VTS_Return_t	CloseDevice(void);
	bool			CheckDevice(void);
	int				GetDeviceIndex(void);
	VTS_Return_t	GetDevicePath(int s4_DeviceIndex, char* s1p_DevicePath);
	VTS_Return_t	GetSerialNum(int s4_DeviceIndex, char* s1p_SerialNum);
	VTS_Return_t	GetSerialNum(char* s1p_SerialNum);
	////////////////////////////////////////////////////////////////////////////

	// Data Pump Control Methods ///////////////////////////////////////////////
	VTS_Return_t	PumpGetID(int s4_DeviceIndex, VTS_PumpID_t* tp_PumpID);
	VTS_Return_t	PumpGetID(VTS_PumpID_t* tp_PumpID);

	VTS_Return_t	PumpSetState(VTS_PumpState_t t_PumpState);
	VTS_Return_t	PumpGetState(VTS_PumpState_t* tp_PumpState);

	VTS_Return_t	PumpGetHwBuffSize(unsigned int* u4p_HwBuffSize); // in Bytes
	VTS_Return_t	PumpGetHwBuffUsed(unsigned int* u4p_HwBuffUsed, unsigned int* u4p_RxBuffUsed = NULL); // in Bytes

	VTS_Return_t	PumpGetRxBuffUnderRun(int* s4p_UnderRun);
	VTS_Return_t	PumpGetTxBuffUnderRun(int* s4p_UnderRun);

	VTS_Return_t	PumpSetMode(
						VTS_PumpMode_t t_PumpMode,
						bool b_RemuxOnOff,
						VTS_TS_Format_t t_OutTsFormat,
						VTS_TS_Format_t t_SrcTsFormat);
	VTS_Return_t	PumpGetMode(
						VTS_PumpMode_t* tp_PumpMode,
						bool* bp_RemuxOnOff,
						VTS_TS_Format_t* tp_OutTsFormat,
						VTS_TS_Format_t* tp_SrcTsFormat);

	VTS_Return_t	PumpSetControl(
						bool b_ModResetN,
						bool b_AttResetN,
						bool b_AsiEqBypass,
						bool b_AsiLoopbackEnable);
	VTS_Return_t	PumpGetControl(
						bool* bp_ModResetN,
						bool* bp_AttResetN,
						bool* bp_AsiEqBypass,
						bool* bp_AsiLoopbackEnable,
						bool* bp_AsiEqCarrierDetectN,
						bool* bp_AsiRx188_204
						);

	VTS_Return_t	PumpSetRawRate(unsigned int u4_bps);
	VTS_Return_t	PumpGetRawRate(unsigned int* u4p_bps);

	VTS_Return_t	PumpSetConvRate(unsigned int u4_bps);
	VTS_Return_t	PumpGetConvRate(unsigned int* u4p_bps);

	VTS_Return_t	PumpGetRxRate(unsigned int* u4p_bps); // for ASI-IN of ASI-RF
	VTS_Return_t	PumpWrite(
						unsigned char* u1p_Buff,
						unsigned int u4_dwWrite, 
						unsigned long* u4p_TransferedBytes,
						bool b_IsDSLFormatForDABModulator = false
					);
	VTS_Return_t	PumpRead(
						unsigned char* u1p_Buff,
						unsigned int u4_dwRead,
						unsigned long* u4p_TransferedBytes
					);

	static const unsigned long WRITE_SIZE_ETI = 6144;
	static const unsigned long WRITE_SIZE_TS = 188*204*16;
	static const unsigned long READ_SIZE_TS = 512*1024;

	VTS_Return_t	PumpGetBcTypeSupport(VTS_BroadcastType_t t_BcType); // Check the Broadcast type capability
	VTS_Return_t	PumpGetAwgnLicence(void);
	VTS_Return_t	PumpGetAtscMhMuxLicense(void);
	VTS_Return_t	PumpGetDmbMuxLicense(void);

	VTS_Return_t PumpGetMaxSrcRate(unsigned int* u4p_bps);
	VTS_Return_t PumpGetMinSrcRate(unsigned int* u4p_bps);
	VTS_Return_t PumpGetMaxConvRate(unsigned int* u4p_bps);
	VTS_Return_t PumpGetMinConvRate(unsigned int* u4p_bps);
	VTS_Return_t PumpGetMaxSymRate(unsigned int* u4p_bps);
	VTS_Return_t PumpGetMinSymRate(unsigned int* u4p_bps);
	bool Pump_DMA_Q_IsFree(void);
	
	////////////////////////////////////////////////////////////////////////////

	// Modulator/UpConverter control methods ///////////////////////////////////
	// Query Methods
	VTS_Return_t	ModulatorGetID(VTS_ModulatorID_t* tp_ModulatorID);
	VTS_Return_t	ModulatorGetRFMax(unsigned int* u4p_Hz);
	VTS_Return_t	ModulatorGetRFMin(unsigned int* u4p_Hz);

	VTS_Return_t	ModulatorInit(VTS_BroadcastType_t t_BcType);

	VTS_Return_t	ModulatorSetBcType(VTS_BroadcastType_t t_BcType);
	VTS_Return_t	ModulatorGetBcType(VTS_BroadcastType_t* tp_BcType);

	VTS_Return_t	ModulatorSetRF(unsigned int u4_Hz);
	VTS_Return_t	ModulatorGetRF(unsigned int *u4p_Hz);

	VTS_Return_t	ModulatorSetIF(unsigned int u4_Hz);
	VTS_Return_t	ModulatorGetIF(unsigned int *u4p_Hz);

	VTS_Return_t	AWGN_Set_CN(double& s8_SNR_dBm, double& s8_BW);
	VTS_Return_t	AWGN_ON_OFF(bool isOnOff);


	// Diagnostic methods
	VTS_Return_t	ModulatorGetPllStatus(
		bool* bp_IF1_Locked, // Baseband to Low IF Up Conversion
		bool* bp_IF2_Locked, // Low IF to High IF Up Conversion !! Not implemented, Always TRUE !!
		bool* bp_RF_Locked); // High IF to RF Down Conversion & Spectrum Inversion  !! Not implemented, Always TRUE !!

	// DVB-T/H Specific Methods
	VTS_Return_t	DVB_TH_SetBandWidth(unsigned char u1_MHz);
	VTS_Return_t	DVB_TH_GetBandWidth(unsigned char* u1p_MHz);
	
	VTS_Return_t	DVB_TH_GetSymRate(unsigned int* u4p_SymRate_bd);
	VTS_Return_t	DVB_TH_GetBitRate(unsigned int* u4p_BitRate_bps);

	VTS_Return_t	DVB_TH_SetCellID(unsigned short u2_CellID);
	VTS_Return_t	DVB_TH_GetCellID(unsigned short *u2p_CellID);

	VTS_Return_t	DVB_TH_SetMode(
						bool b_CellIDEn,
						VTS_DVB_TH_Interleaver_t t_Interleaver,
						bool b_UseMPE_FEC,
						bool b_UseTimeSlicing,
						bool b_DVBHEnable,
						VTS_DVB_TH_GuardInt_t t_GuardInt,
						VTS_DVB_TH_TxMode_t t_TxMode,
						VTS_DVB_TH_Constel_t t_Constel,
						VTS_DVB_TH_CodeRate_t t_CodeRate
					);
	VTS_Return_t	DVB_TH_GetMode(
						bool* bp_CellIDEn,
						VTS_DVB_TH_Interleaver_t* tp_Interleaver,
						bool* bp_UseMPE_FEC,
						bool* bp_UseTimeSlicing,
						bool* bp_DVBHEnable,
						VTS_DVB_TH_GuardInt_t* tp_GuardInt,
						VTS_DVB_TH_TxMode_t* tp_TxMode,
						VTS_DVB_TH_Constel_t* tp_Constel,
						VTS_DVB_TH_CodeRate_t* tp_CodeRate
					);

	VTS_Return_t	DVB_TH_SetCellIDEn(bool b_Enable);
	VTS_Return_t	DVB_TH_GetCellIDEn(bool* bp_Enable);
	VTS_Return_t	DVB_TH_SetInterleaver(VTS_DVB_TH_Interleaver_t t_Interleaver);
	VTS_Return_t	DVB_TH_GetInterleaver(VTS_DVB_TH_Interleaver_t* tp_Interleaver);
	VTS_Return_t	DVB_TH_SetMPE_FEC(bool b_Use);
	VTS_Return_t	DVB_TH_GetMPE_FEC(bool* bp_Use);
	VTS_Return_t	DVB_TH_SetTimeSlicing(bool b_Use);
	VTS_Return_t	DVB_TH_GetTimeSlicing(bool* bp_Use);
	VTS_Return_t	DVB_TH_SetDVBHEnable(bool b_Enable);
	VTS_Return_t	DVB_TH_GetDVBHEnable(bool* bp_Enable);
	VTS_Return_t	DVB_TH_SetGuardInt(VTS_DVB_TH_GuardInt_t t_GuardInt);
	VTS_Return_t	DVB_TH_GetGuardInt(VTS_DVB_TH_GuardInt_t* tp_GuardInt);
	VTS_Return_t	DVB_TH_SetTxMode(VTS_DVB_TH_TxMode_t t_TxMode);
	VTS_Return_t	DVB_TH_GetTxMode(VTS_DVB_TH_TxMode_t* tp_TxMode);
	VTS_Return_t	DVB_TH_SetConstel(VTS_DVB_TH_Constel_t t_Constel);
	VTS_Return_t	DVB_TH_GetConstel(VTS_DVB_TH_Constel_t* tp_Constel);
	VTS_Return_t	DVB_TH_SetCodeRate(VTS_DVB_TH_CodeRate_t t_CodeRate);
	VTS_Return_t	DVB_TH_GetCodeRate(VTS_DVB_TH_CodeRate_t* tp_CodeRate);

	// DVB-C Specific Methods
	VTS_Return_t	DVB_C_SetSymRate(unsigned int u4_DVBCSymRateBd);
	VTS_Return_t	DVB_C_GetSymRate(unsigned int* u4p_SymRate_bd);

	VTS_Return_t	DVB_C_SetBitRate(unsigned int u4_BitRate_bps);
	VTS_Return_t	DVB_C_GetBitRate(unsigned int* u4p_BitRate_bps);

	VTS_Return_t	DVB_C_GetBandWidth(unsigned int* u4p_BW_Hz);

	VTS_Return_t	DVB_C_SetConstel(VTS_DVB_C_Constel_t t_Constel);
	VTS_Return_t	DVB_C_GetConstel(VTS_DVB_C_Constel_t* tp_Constel);

	//DVB-S Specific Methods
	VTS_Return_t	DVB_S_SetSymRate(unsigned int u4_DVBSSymRateBd);
	VTS_Return_t	DVB_S_GetSymRate(unsigned int* u4p_SymRate_bd);

	VTS_Return_t	DVB_S_GetBitRate(unsigned int* u4p_BitRate_bps);

	VTS_Return_t	DVB_S_GetBandWidth(unsigned int* u4p_BW_Hz);

	VTS_Return_t	DVB_S_SetConstel(VTS_DVB_S_Constel_t t_Constel);
	VTS_Return_t	DVB_S_GetConstel(VTS_DVB_S_Constel_t* tp_Constel);

	VTS_Return_t	DVB_S_SetCodeRate(VTS_DVB_S_CodeRate_t t_CodeRate);
	VTS_Return_t	DVB_S_GetCodeRate(VTS_DVB_S_CodeRate_t* tp_CodeRate);
	// QAM-B Specific Methods
	VTS_Return_t	QAM_B_GetSymRate(unsigned int* u4p_SymRate_bd);
	VTS_Return_t	QAM_B_GetBandWidth(unsigned int* u4p_BW_Hz);
	VTS_Return_t	QAM_B_GetBitRate(unsigned int* u4p_BitRate_bps);

	VTS_Return_t	QAM_B_SetConstel(VTS_QAM_B_Constel_t t_Constel);
	VTS_Return_t	QAM_B_GetConstel(VTS_QAM_B_Constel_t* tp_Constel);
	VTS_Return_t	QAM_B_SetInterleaving(VTS_QAM_B_Interleaving_t t_Interleaving);
	VTS_Return_t	QAM_B_GetInterleaving(VTS_QAM_B_Interleaving_t* t_Interleaving);

	VTS_Return_t	QAM_B_SetMode(
						VTS_QAM_B_Constel_t t_Constel,
						VTS_QAM_B_Interleaving_t t_Interleaving
					);
	VTS_Return_t	QAM_B_GetMode(
						VTS_QAM_B_Constel_t* t_Constel,
						VTS_QAM_B_Interleaving_t* t_Interleaving
					);


	// ATSC Specific Mehotds
	VTS_Return_t	ATSC_GetBandWidth(unsigned int* u4p_BW_Hz);
	VTS_Return_t	ATSC_GetSymRate(unsigned int* u4p_SymRate_bd);
	VTS_Return_t	ATSC_GetBitRate(unsigned int* u4p_BitRate_bps);

	// T-DMB Specific Methods
	VTS_Return_t	T_DMB_GetBandWidth(unsigned int* u4p_BW_Hz);
	VTS_Return_t	T_DMB_GetBitRate(unsigned int* u4p_BitRate_bps);
	VTS_Return_t	T_DMB_GetSymRate(unsigned int* u4p_SymRate_bd);
	VTS_Return_t	T_DMB_SetTii(
						bool b_Enable,
						unsigned char u1_MainId,
						unsigned char u1_SubId
					);
	VTS_Return_t	T_DMB_GetTii(
						bool* bp_Enable,
						unsigned char* u1p_MainId,
						unsigned char* u1p_SubId
					);
	VTS_Return_t	T_DMB_Parse(unsigned char* u1p_Buff, unsigned int u4_Size, bool b_IsDSLFormat = false);
	VTS_Return_t	T_DMB_GetMode(int* s4p_Mode);
	VTS_Return_t	T_DMB_GetBufferOffset(int* s4p_Offset);
	VTS_Return_t	T_DMB_GetFramePhase(int* s4p_Phase);

	// ISDB_T Specific Methods
	VTS_Return_t	ISDBT_SetBandWidth(unsigned char u1_MHz);
	VTS_Return_t	ISDBT_GetBandWidth(unsigned char* u1p_MHz);
	VTS_Return_t	ISDB_T_GetSymRate(unsigned int* u4p_SymRate_bd);
	VTS_Return_t	ISDBT_Parse(unsigned char *u1p_Buff, int s4_Size_Byte);
	VTS_Return_t	ISDBT_Parse(const char* p_FilePath);
	VTS_Return_t	ISDBT_Parse(const wchar_t* p_FilePath);
	VTS_Return_t	ISDBT_GetBufferOffset(int *s4p_Offset);
	VTS_Return_t	ISDBT_GetFrameSize(int *s4p_FrameSize);		
	VTS_Return_t	ISDBT_SetParameter(VTS_ISDB_T_Layer_t t_Layer, ISDB_Layer_Parameter_t t_NewParameter);
	VTS_Return_t	ISDBT_GetParameter(
						ISDB_Layer_Parameter_t* tp_Layer_A,
						ISDB_Layer_Parameter_t* tp_Layer_B,
						ISDB_Layer_Parameter_t* tp_Layer_C,
						ISDB_OfdmConfig_t* tp_OfdmConfig
					);
	ISDB_Layer_Parameter_t ISDBT_GetLayerParameter(VTS_ISDB_T_Layer_t t_Layer);
	VTS_Return_t	ISDBT_GetTotalOutBitRate(unsigned int *u4p_BitRatebps);
	VTS_Return_t	ISDBT_GetLayerOutBitRate(unsigned int* u4p_BitRateBps, VTS_ISDB_T_Layer_t t_Layer);
	VTS_Return_t	ISDBT_GetLayerSrcBitRate(unsigned int* u4p_BitRateBps, VTS_ISDB_T_Layer_t t_Layer);
	VTS_Return_t	ISDBT_GetTotalSrcBitRate(unsigned int* u4p_BitRateBps);
	VTS_Return_t	ISDBT_GetTspNumPerFrame(unsigned int *u4p_TspNumPerFrame);	
	VTS_Return_t	ISDBT_IsISDBT_TS(const char* p_FilePath, bool *b_IsIsdbtTs);
	VTS_Return_t	ISDBT_IsISDBT_TS(const wchar_t* p_FilePath, bool *b_IsIsdbtTs);	
	VTS_Return_t	ISDBT_SetOfdmConfig(ISDB_OfdmConfig_t t_NewConfig);
	ISDB_OfdmConfig_t ISDBT_GetOfdmConfig();	
	VTS_Return_t	ISDBT_SetFullSegOut(bool b_IsFullSegOut);
	VTS_Return_t	ISDBT_GetFullSegOut(bool* bp_IsFullSegOut);	
	VTS_Return_t	ISDBT_SetEws(bool b_SetEws);
	VTS_Return_t	ISDBT_GetEws(bool& b_SetEws);

	// CMMB Specific Methods	
	VTS_Return_t	CMMB_GetSymRate(unsigned int* u4p_SymRate_bd);
	VTS_Return_t	CMMB_IsCMMB_TS(const char* p_FilePath, bool* b_IsCmmbTs);
	VTS_Return_t	CMMB_IsCMMB_TS(const wchar_t* p_FilePath, bool* b_IsCmmbTs);
	VTS_Return_t	CMMB_CHECK_SYNC(const char* p_FilePath, unsigned __int64 u8_CurrentPosition, int* s4p_Offset, int* s4p_FrameSize, 
									bool IsMultiCh, CmmbConfig_t t_Config, unsigned char* u1p_Buffer);
	VTS_Return_t	CMMB_CHECK_SYNC(const wchar_t* p_FilePath, unsigned __int64 u8_CurrentPosition, int* s4p_Offset, int* s4p_FrameSize, 
									bool IsMultiCh, CmmbConfig_t t_Config, unsigned char* u1p_Buffer);
	CmmbClchCheck_t	CMMB_PARSING(const char* p_FilePath, bool* bp_IsMultiCh, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
	CmmbClchCheck_t	CMMB_PARSING(const wchar_t* p_FilePath, bool* bp_IsMultiCh, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
	VTS_Return_t	CMMB_GetConfig(CmmbConfig_t* tp_Config);
	VTS_Return_t	CMMB_GetChangeableTSlot(CmmbConfig_t* tp_Config);
	VTS_Return_t	CMMB_ChangeParameter(unsigned char u1_MfId, CmmbInformation_t t_Parameter);
	VTS_Return_t	CMMB_Initial();	
	VTS_Return_t	CMMB_GetRevision(CmmbConfig_t t_Config, bool IsMulti, double* f8p_Revision);
	VTS_Return_t	CMMB_AddSMfs(const char* p_FilePath, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
	VTS_Return_t	CMMB_AddSMfs(const wchar_t* p_FilePath, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
	VTS_Return_t	CMMB_DeleteSMfs(int s4_MfId);	
	VTS_Return_t	CMMB_GetOutBitRate(unsigned int* u4p_OutBitRate);
	VTS_Return_t	CMMB_GetMfOutBitRate(unsigned int* u4p_OutBitRate, int s4_MfId);		//bit rate for individual MF
	int			CMMB_CheckMfSize(bool b_IsMulti, unsigned char u1_MfId, unsigned char* u1p_Buffer, int s4_RemainBuffSize = 1024*1024*8);
	VTS_Return_t	CMMB_TransTs2Mfs(unsigned char* u1p_Buffer, int s4_Size);
	bool*		CMMB_GetEmptyFrame();
	
	//DTMB Specific Methods
	VTS_Return_t	DTMB_Initial();
	VTS_Return_t	DTMB_IsDTMBTS(const char* p_FilePath, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
	VTS_Return_t	DTMB_IsDTMBTS(const wchar_t* p_FilePath, unsigned int* s4p_Offset, unsigned int* s4p_FrameSize);
	VTS_Return_t	DTMB_GetSrcBitRate(int* s4p_BitRate);
	VTS_Return_t	DTMB_GetOutBitRate(int* s4p_BitRate);
	VTS_Return_t	DTMB_GetSymRate(unsigned int* u4p_SymRate_bd);	
	VTS_Return_t	DTMB_GetRevision(VTS_DTMB_CONFIG_t t_Config, double* f8p_Revision, int s4_TsLength);

	VTS_Return_t	DTMB_SetMode(VTS_DTMB_CONFIG_t t_Config, unsigned int* u4p_NewFrameSz);
	VTS_Return_t	DTMB_GetMode(VTS_DTMB_CONFIG_t* tp_Config);

	//DVB-S2 Specific Methods
	VTS_Return_t	DVBS2_Initial();

	VTS_Return_t	DVBS2_ParseStream(const wchar_t* p_FilePath);
	VTS_Return_t	DVBS2_ParseStream(const char* p_FilePath);
	VTS_Return_t	DVBS2_SetParam(unsigned int u4_SymRate_bd, VTS_DVB_S2_Constel_t t_Constellation, VTS_DVB_S2_CodeRate_t t_CodeRate, 
														bool b_IsPilotInsert, VTS_DVB_S2_Alpha_t t_RollOff);
	
	VTS_Return_t	DVBS2_GetSrcBitRate(unsigned int* u4p_BitRate_bps);
	VTS_Return_t	DVBS2_GetOutBitRate(unsigned int* u4p_BitRate_bps);	
	VTS_Return_t	DVBS2_GetBandwidth(unsigned int* u4p_BW_Hz);
	VTS_Return_t	DVBS2_GetDmaSize(unsigned int* u4p_DmaSize);

	VTS_Return_t	DVBS2_SetSymRate( unsigned int u4_SymRate_bd);	
	VTS_Return_t	DVBS2_GetSymRate(unsigned int* u4p_SymRate_bd);
	
	VTS_Return_t	DVBS2_SetConstellation(VTS_DVB_S2_Constel_t t_Constellation);
	VTS_Return_t	DVBS2_GetConstellation(VTS_DVB_S2_Constel_t* tp_Constellation);
	
	VTS_Return_t	DVBS2_SetCodeRate(VTS_DVB_S2_CodeRate_t t_CodeRate);
	VTS_Return_t	DVBS2_GetCodeRate(VTS_DVB_S2_CodeRate_t* tp_CodeRate);
	
	VTS_Return_t	DVBS2_SetRollOff(VTS_DVB_S2_Alpha_t t_RollOff);
	VTS_Return_t	DVBS2_GetRollOff(VTS_DVB_S2_Alpha_t* tp_RollOff);

	VTS_Return_t	DVBS2_SetPilotInsertion(bool b_IsPilotInsert);
	VTS_Return_t	DVBS2_GetPilotInsertion(bool* bp_IsPilotInsert);
	//DVB-T2 Specific Methods
	VTS_Return_t	DVBT2_ParseStream(const char* sz_FilePath, bool b_IsT2Mi, bool b_IsReplace);
	VTS_Return_t	DVBT2_ParseStream(const wchar_t* sz_FilePath, bool b_IsT2Mi, bool b_IsReplace);
	VTS_Return_t	DVBT2_GetError(OUT wchar_t* sz_ErrorString, int& s4_StrLength);		//sz_ErrorString IAIAi CͨACAOa
	
	VTS_Return_t	DVBT2_SetFFT(VTS_DVBT2_FFT_SIZE_e e_FftSize);
	VTS_Return_t	DVBT2_SetGuardInterval(VTS_DVBT2_GI_e e_GuardInterval);
	VTS_Return_t	DVBT2_SetBW(VTS_DVBT2_BW_e e_BandWidth);
	VTS_Return_t	DVBT2_SetL1MOD(VTS_DVBT2_L1POSTMOD_e e_L1PostMod);
	VTS_Return_t	DVBT2_SetPilotPattern(VTS_DVBT2_PP_e e_Pp);
	VTS_Return_t	DVBT2_SetT2FramesPerSuperFrame(int s4_T2FramesN);
	VTS_Return_t	DVBT2_SetDataSymbolsN(int s4_DataSymbolsN);
	VTS_Return_t	DVBT2_SetVersion(VTS_DVBT2_VERSION_e e_Version);
	VTS_Return_t	DVBT2_SetSubSlicesN(int s4_SubSlicesN);
	VTS_Return_t	DVBT2_SetL1Repetion(bool b_L1Repetition);
	VTS_Return_t	DVBT2_SetBwtExt(bool b_BwtExt);	
	VTS_Return_t	DVBT2_SetT2SystemID(int s4_T2SystemID);
	VTS_Return_t	DVBT2_SetNetworkID(int s4_NetworkID);
	VTS_Return_t	DVBT2_SetCellID(int s4_CellID);	

	VTS_Return_t	DVBT2_SetPlpMaxBlock(int s4_PlpId, int s4_PlpMaxBlock);
	VTS_Return_t	DVBT2_SetPlpMapping(int s4_PlpId, VTS_DVBT2_PLP_MAPPING_e e_PlpMapping);
	VTS_Return_t	DVBT2_SetPlpRotation(int s4_PlpId, bool b_Rotation);
	VTS_Return_t	DVBT2_SetPlpCodeRate(int s4_PlpId, VTS_DVBT2_LDPC_e e_CodeRate);
	VTS_Return_t	DVBT2_SetPlpFecType(int s4_PlpId, VTS_DVBT2_FECTYPE_e e_FecType);
	VTS_Return_t	DVBT2_SetIntrlType(int s4_PlpId, int s4_IntrlType);
	VTS_Return_t	DVBT2_SetIntrlLength(int s4_PlpId, int s4_IntrlLength);
	VTS_Return_t	DVBT2_SetFrameInterval(int s4_PlpId, int s4_FrameInterval);
	VTS_Return_t	DVBT2_SetPlpType(int s4_PlpId, VTS_DVBT2_PlpType_e e_PlpType);
	


	VTS_Return_t	DVBT2_GetPlpN(int* s4p_PlpN);
	VTS_Return_t	DVBT2_GetPlpParam(int s4_PlpIndex, VTS_DVBT2_PLP_Infor_t* tp_PlpInfor);
	VTS_Return_t	DVBT2_GetGeneralParam(VTS_DVBT2_SYSTEM_Infor_t* tp_Infor);
	VTS_Return_t	DVBT2_GetDmaSize(unsigned int* s4p_DmaSize);
	//ATSC-MH Specific Methods (Non-Multiplex Mode Support)
	VTS_Return_t ATSC_MH_Init(VOID);

	VTS_Return_t ATSC_MH_SetMainTSPath(wchar_t w_PathBuffer[]);
	VTS_Return_t ATSC_MH_GetMainTSPath(wchar_t w_PathBuffer[], int s4_PathBufferLength);
	
	VTS_Return_t ATSC_MH_GetLegacyBitRate(unsigned int & s4_BitRate_bps);

	VTS_Return_t ATSC_MH_SetUseLegacy(bool isUse);
	VTS_Return_t ATSC_MH_GetUseLegacy(bool* isUse);

	VTS_Return_t ATSC_MH_GetFrameSize(unsigned int* u4p_FrameSize);


	// CW Specific Methods
	VTS_Return_t	CW_GetSymRate(unsigned int* u4p_SymRate_bd);
	VTS_Return_t	CW_SetLevel_20dBm(void); // Set Output level to -20dBm
	unsigned short	CW_GetLevelCtrl_20dBm(void);
	VTS_Return_t	CW_SetLevelCtrl(unsigned short u2_LevelCtrl); // Output Level Control Coef.
	VTS_Return_t	CW_GetLevelCtrl(unsigned short* u2p_LevelCtrl);
	unsigned short	CW_GetLevelCtrlMax(void);

	VTS_Return_t	Analog_FM_SetSymRate(unsigned int u4_SymRateBd);
	VTS_Return_t	Analog_FM_GetSymRate(unsigned int *u4p_SymRate_bd);
	VTS_Return_t	Analog_FM_GetBitRate(unsigned int *u4p_BitRate_bps);
	VTS_Return_t	Analog_FM_GetBandWidth(unsigned int *u4p_BW_Hz);
	VTS_Return_t	Analog_FM_SetArbRate(unsigned int u4_ArbRateHz);
	VTS_Return_t	Analog_FM_GetArbRate(unsigned int *u4p_ArbRateHz);
	VTS_Return_t	Analog_FM_SetDevFactor(unsigned int u4_DevFactor); // Deviation Factor
	VTS_Return_t	Analog_FM_GetDevFactor(unsigned int *u4p_DevFactor); // Deviation Factor
	VTS_Return_t	Analog_FM_SetArbBypassFlag(unsigned int u4_bypassFlag);
	VTS_Return_t	Analog_FM_GetArbBypassFlag(unsigned int *u4p_bypassFlag);
	VTS_Return_t	Analog_FM_SetInt2xBypassFlag(unsigned int u4_bypassFlag);
	VTS_Return_t	Analog_FM_GetInt2xBypassFlag(unsigned int *u4p_bypassFlag);
	VTS_Return_t	Analog_FM_SetDevTestMode(unsigned int u4_testFlag);
	VTS_Return_t	Analog_FM_GetDevTestMode(unsigned int *u4p_testFlag);	
	VTS_Return_t	Analog_FM_SetDevTestValue(unsigned int u4_testVal);
	VTS_Return_t	Analog_FM_GetDevTestValue(unsigned int *u4p_testVal);
	VTS_Return_t	Analog_FM_SetAwgn(unsigned int u4_awgn);
	VTS_Return_t	Analog_FM_GetAwgn(unsigned int *u4p_awgn);	
	VTS_Return_t	Hdradio_SetSymRate(unsigned int u4_SymRateBd);	
	VTS_Return_t	Hdradio_GetSymRate(unsigned int *u4p_SymRate_bd);	
	VTS_Return_t	Hdradio_GetBitRate(unsigned int *u4p_BitRate_bps);	
	VTS_Return_t	Hdradio_GetBandWidth(unsigned int *u4p_BW_Hz);	
	VTS_Return_t	Hdradio_SetArbRate(unsigned int u4_ArbRateHz);	
	VTS_Return_t	Hdradio_GetArbRate(unsigned int *u4p_ArbRateHz);
	VTS_Return_t	Hdradio_SetFlags(unsigned int u4_flags);	
	VTS_Return_t	Hdradio_GetFlags(unsigned int *u4p_flags);
	VTS_Return_t	Hdradio_SetArbBypassFlag(bool b_bypassFlag);	
	VTS_Return_t	Hdradio_GetArbBypassFlag(bool *bp_bypassFlag);
	VTS_Return_t	Hdradio_SetInt2xBypassFlag(bool b_bypassFlag);
	VTS_Return_t	Hdradio_GetInt2xBypassFlag(bool *bp_bypassFlag);	
	//-------------------------------------------------------------------------------
	//VentusAPlus Tuner
	//-------------------------------------------------------------------------------
	int VentusAPlus_Tuner_CountDevice();
	VTS_Return_t VentusAPlus_Tuner_PowerDetect();
	VTS_Return_t VentusAPlus_Tuner_Standard_Initialize(VTS_TunerStandard_t t_TunerStd);
	VTS_Return_t VentusAPlus_Tuner_SetFreq(unsigned int u4_FreqHz);
	VTS_Return_t VentusAPlus_Tuner_GetFreq(unsigned int *u4p_FreHz);
	VTS_Return_t VentusAPlus_Tuner_GetFreqSpec(unsigned int *u4p_FreqMinHz, unsigned int *u4p_FreqMaxHz);

	//-------------------------------------------------------------------------------
	//VentusAPlus Tuner In Path, In/Out Port Type
	//-------------------------------------------------------------------------------
	VTS_Return_t VentusAPlus_Input_SetPath(VtsAPlus_RxPath_t t_Path);
	VTS_Return_t VentusAPlus_Input_GetPath(VtsAPlus_RxPath_t *tp_Path);

	VTS_Return_t VentusAPlus_Input_SetPortType(VtsAPlus_PortType_t t_Type);
	VTS_Return_t VentusAPlus_Input_GetPortType(VtsAPlus_PortType_t *tp_type);

	VTS_Return_t VentusAPlus_Output_SetPortType(VtsAPlus_PortType_t t_Type);
	VTS_Return_t VentusAPlus_Output_GetPortType(VtsAPlus_PortType_t *tp_type);

	//-------------------------------------------------------------------------------
	//VentusAPlus Tuner Get Info
	//-------------------------------------------------------------------------------
	
	//
	//VentusAPlus_Tuner_GetSNR : VSB, QAM
	VTS_Return_t VentusAPlus_Tuner_GetSNR(double *d8p_SNR);

	//
	//VentusAPlus_Tuner_GetRSSI : VSB, QAM
	VTS_Return_t VentusAPlus_Tuner_GetRSSI(int *s4p_dBm);	

	//
	//VentusAPlus_Tuner_GetSyncLock :  VSB, QAM
	VTS_Return_t VentusAPlus_Tuner_GetSyncLock(bool *bp_IsSLock);

	//
	// VentusAPlus_Tuner_GetPacketErr :  VSB, QAM : (monitoring error counts in packets at every one second)
	VTS_Return_t VentusAPlus_Tuner_GetPacketErrCounts(unsigned short *u2p_PacketErrorCounts);

	//
	//VentusAPlus_Tuner_GetFreqOffset : VSB, QAM : monitoring offsets for the carrier frequency
	VTS_Return_t VentusAPlus_Tuner_GetFreqOffset(float *f4p_FreqOffset);
	
	//
	//VentusAPlus_Tuner_GetScat : VSB, QAM : monitoring I and Q of the constellation
	VTS_Return_t VentusAPlus_Tuner_GetScat(short *s2p_I, short *s2p_Q);

	//
	//VentusAPlus_Tuner_GetDCValue : VSB Only : monitoring DC Value of VSB DC Remover
	VTS_Return_t VentusAPlus_Tuner_GetDCValue(unsigned char *u1p_DCValue);
	
	//
	//VentusAPlus_Tuner_GetIntMode : VSB, QAM : monitoring the number of taps and the increases of the input signal
	VTS_Return_t VentusAPlus_Tuner_GetIntMode(unsigned char *u1p_I, unsigned char *u1p_J);

	//
	//VentusAPlus_Tuner_GetRFSignalCondition : VSB, QAM
	//8vsb (No : ~0, weak : 0 ~10, moderate : 10 ~16, strong : 16 ~24, very strong : 24 ~)
	//64qam (No : ~0, weak : 0 ~20, moderate : 20 ~25, strong : 26 ~30, very strong : 31 ~)
	//256qam (No : ~0, weak : 0 ~28, moderate : 28 ~30, strong : 31 ~32, very strong : 33 ~)
	VTS_Return_t VentusAPlus_Tuner_GetRFSignalCondition(VtsAPlus_RFSignalCondition_t *tp_SignalCondition);

	//
	//VentusAPlus_Tuner_GetCarrierRecoveryLock : VSB, QAM
	VTS_Return_t VentusAPlus_Tuner_GetCarrierRecoveryLock(bool *bp_IsCRLock);

	//
	//VentusAPlus_Tuner_GetTimingRecoveryLock : QAM Only
	VTS_Return_t VentusAPlus_Tuner_GetTimingRecoveryLock(bool *bp_IsTRLock);

	//
	//VentusAPlus_Tuner_GetFECLock : QAM Only
	VTS_Return_t VentusAPlus_Tuner_GetFECLock(bool *bp_IsViterbi, bool *bp_IsFec, bool *bp_IsMpeg);

	//-------------------------------------------------------------------------------
	//VentusAPlus SMPTE
	//-------------------------------------------------------------------------------
	VTS_Return_t VentusAPlus_Input_ASI_SMPTE_GetLock(bool *bp_IsASLock);
	VTS_Return_t VentusAPlus_Output_is_SMPTE_SetPLL(VtsAPlus_SMPTE_PLLType_t t_PLLType);

	//-------------------------------------------------------------------------------
	//VentusAPlus Temperature Monitoring
	//-------------------------------------------------------------------------------
	VTS_Return_t VentusAPlus_Tuner_GetTemperature(char *s1p_Temperature);
	
	////////////////////////////////////////////////////////////////////////////

	// Amplifier & Attenuator, Level Controller module control methods /////////
	VTS_Return_t AttenGetID(VTS_AttenuatorID_t* tp_AttenuatorID); // If it fails, this module isn't attached.

	bool		 AttenGetExistence(void);
	VTS_Return_t AttenGetOutLevelMax(short* s2p_OutLevel_01dBm, short* s2p_1GHz_Over_OutLevel_01dBm_For_Ventus2 = NULL);
	VTS_Return_t AttenGetOutLevelMin(short* s2p_OutLevel_01dBm, short* s2p_1GHz_Over_OutLevel_01dBm_For_Ventus2 = NULL);

	VTS_Return_t AttenGetFrequencyMax(unsigned int* u4p_Freq_Hz);
	VTS_Return_t AttenGetFrequencyMin(unsigned int* u4p_Freq_Hz);

	VTS_Return_t AttenSetOutLevel(short s2_OutLevel_01dBm);
	VTS_Return_t AttenGetOutLevel(short* s2p_OutLevel_01dBm);
	VTS_Return_t AttenSetFrequency(unsigned int u4_Freq_Hz);
	VTS_Return_t AttenGetFrequency(unsigned int* u4p_Freq_Hz);
	VTS_Return_t AttenGetTemperature(char* s1p_Temp_Celsius);
	VTS_Return_t AttenSetOutSwitch(unsigned char u1_OnOff);
	VTS_Return_t AttenGetOutSwitch(unsigned char* u1p_OnOff);
	////////////////////////////////////////////////////////////////////////////
	VTS_Return_t UpConvGetTemperature(char* s1p_Temp_Celsius);
	VTS_Return_t UpConvGetID(VTS_UpConverterID_t* tp_UpConvID); 

	
	////////////////////////////////////////////////////////////////////////////
	//For Sirch Model
	////////////////////////////////////////////////////////////////////////////
	VTS_Return_t UpConvRfOutWatch(unsigned int* u4p_RfOutWatch);
	VTS_Return_t UpConvVoltageWatch(unsigned int* u4p_VoltageWatch);
	////////////////////////////////////////////////////////////////////////////

	
	VTS_Return_t SkyBandGetID(VTS_SkyBandID_t* tp_SkyBandID); 
	bool		 SkyBandGetExistence(void);
	VTS_Return_t SkyBandGetOutLevelMax(short* s2p_OutLevelMax_01dBm);
	VTS_Return_t SkyBandGetOutLevelMin(short* s2p_OutLevelMin_01dBm);
	VTS_Return_t SkyBandGetFrequencySBandMax(unsigned int* u4p_S_BandRF_MaxHz);
	VTS_Return_t SkyBandGetFrequencySBandMin(unsigned int* u4p_S_BandRF_MinHz);
	VTS_Return_t SkyBandGetFrequencyLBandMax(unsigned int* u4p_L_BandRF_MaxHz);
	VTS_Return_t SkyBandGetFrequencyLBandMin(unsigned int* u4p_L_BandRF_MinHz);

	////////////////////////////////////////////////////////////////////////////
	/////////////////////////// EEPROM Read, Write //////////////////////////////
	////////////////////////////////////////////////////////////////////////////
	///////////////////EEPAddr : 1K(0 ~ 1023), DataSize : 1K/////////////////////////
	////////////////////////////////////////////////////////////////////////////
	
	VTS_Return_t  EEPROM_SaveUserData(int EEPAddr, unsigned char* pBuffer, int NumBytesToSave);
	VTS_Return_t  EEPROM_LoadUserData(int EEPAddr, unsigned char* pBuffer, int BytesToLoad);

	VTS_Return_t GetFreeSizeOfBuffer(unsigned int* u4p_FreeSize);

public:
	unsigned long mu4_DMA_OutSize;

private:
	char					ms1a_Version[VTS_VERSION_STRING_LENGTH+1];
	VTS_ApiVersion_t		mt_Version;

	wchar_t				ms1aa_DevicePath[VTS_API_MAX_ADAPTER][VTS_API_DEVICE_PATH_MAX+1];
	int					ms4_DeviceIndex;
	unsigned int			mu4_DeviceCount;
	HANDLE 				mh_DeviceHandle;

	VTS_DriverVersion_t	mt_DriverVersion;
	VTS_ModulatorID_t		mt_ModulatorID;
	VTS_PumpID_t			mt_PumpID;
	VTS_AttenuatorID_t		mt_AttenuatorID;
	bool					mb_AttenuatorExist; // Valid after AttenGetID or AttenGetExistence

	VTS_PumpMode_t 		mt_PumpMode;  //ASI_OUT, ASI_RF, RF_OUT ...
	VTS_PumpState_t		mt_PumpState;	// RUN/STOP/STOP_CLR
	VTS_TS_Format_t		mt_SrcTsFormat;	// 188/204
	VTS_TS_Format_t		mt_OutTsFormat;	// 188/204
	bool					mb_RemuxOnOff;

	VTS_BroadcastType_t 	mt_BcType;
	unsigned int			mu4_RawRate_bps;
	unsigned int			mu4_ConvRate_bps;

	bool					mb_CmmbIsMultiCh;		

	VTS_SkyBandID_t 		mt_SkyBandID; //for skyband
	bool					mb_SkyBandExist;
	unsigned int 			mu4_FreqHz;
	short				ms2_OutLvl01dBm;

	unsigned int 			mu4_TunerFreqHz;

	VTS_TunerID_t		mt_TunerID;
	VTS_DemodID_t		mt_DemodID;
	VTS_TunerStandard_t	mt_TunerStd;
};

////////////////////////////////////////////////////////////////////////////////

#endif // CVtsAPI_H
